summaryrefslogtreecommitdiffstats
path: root/kcontrol/input
diff options
context:
space:
mode:
Diffstat (limited to 'kcontrol/input')
-rw-r--r--kcontrol/input/xcursor/themepage.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kcontrol/input/xcursor/themepage.cpp b/kcontrol/input/xcursor/themepage.cpp
index 93221df17..d716b9ab5 100644
--- a/kcontrol/input/xcursor/themepage.cpp
+++ b/kcontrol/input/xcursor/themepage.cpp
@@ -76,7 +76,7 @@ struct ThemeInfo {
static TQString defaultThemeDescription( const TQString& theme )
{
if( theme == "redglass" || theme == "whiteglass" || theme == "pseudocore" || theme == "handhelds" )
- return i18n( "XFree theme %1 - incomplete for KDE" ).arg( theme );
+ return i18n( "XFree theme %1 - incomplete for TDE" ).arg( theme );
return i18n( "No description available" );;
}
@@ -143,7 +143,7 @@ void ThemePage::save()
c.setGroup( "Mouse" );
c.writeEntry( "cursorTheme", selectedTheme != "system" ? selectedTheme : TQString::null );
- KMessageBox::information( this, i18n("You have to restart KDE for these "
+ KMessageBox::information( this, i18n("You have to restart TDE for these "
"changes to take effect."), i18n("Cursor Settings Changed"),
"CursorSettingsChanged" );
@@ -161,7 +161,7 @@ void ThemePage::load( bool useDefaults )
const char *theme = XcursorGetTheme( x11Display() );
currentTheme = theme;
// Get the name of the theme KDE is configured to use
KConfig c( "kcminputrc" );
c.setReadDefaults( useDefaults );
c.setGroup( "Mouse" );
@@ -161,7 +161,7 @@ void ThemePage::load( bool useDefaults )
const char *theme = XcursorGetTheme( x11Display() );
currentTheme = theme;
- // Get the name of the theme KDE is configured to use
+ // Get the name of the theme TDE is configured to use
KConfig c( "kcminputrc" );
c.setReadDefaults( useDefaults );